==> neo4j-procedure-4.4.8-sources.jar: org/neo4j/procedure/impl/TransactionStatusDetailsProvider.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.procedure.impl;

import org.neo4j.function.ThrowingFunction;
import org.neo4j.internal.kernel.api.exceptions.ProcedureException;
import org.neo4j.kernel.api.procedure.Context;
import org.neo4j.procedure.StatusDetailsAccessor;

public class TransactionStatusDetailsProvider implements ThrowingFunction<Context,StatusDetailsAccessor,ProcedureException>
{
    @Override
    public StatusDetailsAccessor apply( Context context ) throws ProcedureException
    {
        var ktx = context.internalTransaction().kernelTransaction();
        return new StatusDetailsAccessor()
        {
            @Override
            public void setStatusDetails( String statusDetails )
            {
                ktx.setStatusDetails( statusDetails );
            }

            @Override
            public String statusDetails()
            {
                return ktx.statusDetails();
            }
        };
    }
}

==> neo4j-procedure-5.7.0-sources.jar: org/neo4j/procedure/impl/TransactionStatusDetailsProvider.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.procedure.impl;

import org.neo4j.function.ThrowingFunction;
import org.neo4j.internal.kernel.api.exceptions.ProcedureException;
import org.neo4j.kernel.api.procedure.Context;
import org.neo4j.procedure.StatusDetailsAccessor;

public class TransactionStatusDetailsProvider
        implements ThrowingFunction<Context, StatusDetailsAccessor, ProcedureException> {
    @Override
    public StatusDetailsAccessor apply(Context context) throws ProcedureException {
        var ktx = context.internalTransaction().kernelTransaction();
        return new StatusDetailsAccessor() {
            @Override
            public void setStatusDetails(String statusDetails) {
                ktx.setStatusDetails(statusDetails);
            }

            @Override
            public String statusDetails() {
                return ktx.statusDetails();
            }
        };
    }
}
